==> meerk-0.1.3-py2-none-any.whl: meerk/status/SlackStatus.py <==
# MIT License
#
# Copyright (c) 2018 Alexey Nikitin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from slackclient import SlackClient

from Status import Status
from SyncException import SyncException


class SlackStatus(Status):

    def __init__(self, sc, text, emoji):
        # type: (SlackClient, str, str) -> SlackStatus
        self.sc = sc
        self.text = text
        self.emoji = emoji

    def sync(self):
        # type: () -> None
        result = self.sc.api_call(
            'users.profile.set',
            profile={
                'status_text': self.text,
                'status_emoji': self.emoji
            }
        )
        if not result['ok']:
            raise SyncException("Can not sync slack status, because {0}".format(result['error']))

==> meerk-0.2.2-py2-none-any.whl: meerk/status/SlackStatus.py <==
# MIT License
#
# Copyright (c) 2018 Alexey Nikitin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from ..slack import Api

from Status import Status
from SyncException import SyncException


class SlackStatus(Status):

    def __init__(self, slack, text, emoji):
        # type: (Api, str, str) -> SlackStatus
        self.slack = slack
        self.text = text
        self.emoji = emoji

    def sync(self):
        # type: () -> None
        result = self.slack.call(
            'users.profile.set',
            profile={
                'status_text': self.text,
                'status_emoji': self.emoji
            }
        )
        if not result['ok']:
            raise SyncException("Can not sync slack status, because {0}".format(result['error']))
